@@ -1,13 +1,15 @@
 gensample <- function(law.index, n, law.pars = NULL, check = TRUE) {
 
   if(getRversion() < "3.1") dontCheck <- identity
+
+  Claw.name <- paste("law",law.index,sep="")
   
   if (check) {  # The following instruction takes time! This is why the check argument exists.
     tmp <- names(getDLLRegisteredRoutines("PoweR")[[".C"]])
     ind.laws <- grep("law",tmp[grep("law",tmp)])
     if (!(law.index %in% ind.laws)) stop(paste("This law (",law.index,") has not been included in the package!",sep=""))
 
-    name <- .C(dontCheck(paste("law",law.index,sep="")),0L,0.0,name=rep(" ",50),1L,rep(0.0,4),0L,1L,PACKAGE="PoweR")$name
+    name <- .C(dontCheck(Claw.name),0L,0.0,name=rep(" ",50),1L,rep(0.0,4),0L,1L,PACKAGE="PoweR")$name
     law.name <- gsub('\\','',gsub('$','',sub(' +$', '', paste(name,collapse="")),fixed=TRUE),fixed=TRUE)
 
     if (length(law.pars) > 4) stop("The maximum number of law parameters is 4. Contact the package author to increase this value.")      
@@ -17,7 +19,7 @@ gensample <- function(law.index, n, law.pars = NULL, check = TRUE) {
 
   if (is.null(law.pars)) {law.pars <- rep(0.0,4);nbparlaw <- 0L} else {nbparlaw <- length(law.pars);law.pars <- c(law.pars,rep(0.0,4-nbparlaw))}
   
-  out <- .C(dontCheck(paste("law",law.index,sep="")),as.integer(n),x=rep(0.0,n),rep(" ",50),0L,
+  out <- .C(dontCheck(Claw.name),as.integer(n),x=rep(0.0,n),rep(" ",50),0L,
             law.pars=as.double(law.pars),nbparlaw=as.integer(nbparlaw),1L,PACKAGE="PoweR")
   
   return(list(sample=out$x,law=law.name,law.pars=out$law.pars[1:out$nbparlaw]))
