@@ -1,5 +1,7 @@
 getnbparlaws <- function(law.indices=NULL) {
   
+  if(getRversion() < "3.1") dontCheck <- identity
+  
   tmp <- names(getDLLRegisteredRoutines("PoweR")[[".C"]])
   ind.laws <- grep("law",tmp[grep("law",tmp)])
   if (!all(law.indices %in% ind.laws)) stop(paste("The values",paste(law.indices[which(!(law.indices %in% ind.laws))],collapse=" ")," in 'law.indices' do not correspond to any defined law!",collapse=""))
@@ -10,8 +12,8 @@ getnbparlaws <- function(law.indices=NULL) {
   nbparlaws.list <- as.vector(rep(0,lst))
   
   for (i in 1:lst) {
-    name.law <- paste("law",law.indices[i],sep="")
-    nbparlaws.list[i] <- (.C(name.law,1L,0.0,rep(" ",50),1L,rep(0.0,4),nbparamlaw=1L,1L,PACKAGE="PoweR"))$nbparamlaw
+    Claw.name <- paste("law",law.indices[i],sep="")
+    nbparlaws.list[i] <- (.C(dontCheck(Claw.name),1L,0.0,rep(" ",50),1L,rep(0.0,4),nbparamlaw=1L,1L,PACKAGE="PoweR"))$nbparamlaw
   }
   
   return(nbparlaws.list)
